package consume

import (
	"query-service/internal/drivers/brokerdriver"
	"query-service/internal/usecases/databaseinfo"
	"query-service/internal/usecases/produce"
	"query-service/internal/usecases/request"

	"git.science.uu.nl/datastrophe/query-conversion"
)

// Service wraps consumer methods
// broker is Alice broker created in brockerdriver driver
type Service struct {
	broker              brokerdriver.Broker
	producer            produce.UseCase
	queryConverter      query.Converter
	requestSender       request.UseCase
	databaseInfoService databaseinfo.UseCase
}

// NewService creates a new service
func NewService(broker brokerdriver.Broker, produceService produce.UseCase, queryConverter query.Converter, requestSenderService request.UseCase, databaseInfoService databaseinfo.UseCase) *Service {
	return &Service{
		broker:              broker,
		producer:            produceService,
		queryConverter:      queryConverter,
		requestSender:       requestSenderService,
		databaseInfoService: databaseInfoService,
	}
}

// Start starts consuming
func (s *Service) Start() {

	// Create consumer
	consumer := s.broker.CreateConsumer()

	consumer.SetMessageHandler(s.HandleMessage)

	// Start consuming messages
	consumer.ConsumeMessages()
}
